@@ -1,4 +1,4 @@
-/****************************f***********************************************
+/***************************************************************************
                           klog.h  -  description
                              -------------------
     begin                : sb dic  7 18:42:45 CET 2002
@@ -63,7 +63,7 @@
 #include "ui_klog.h"
 // The next two are for the cluster box
 #include <QTcpSocket>
-#include <QUrl>
+//#include <QUrl>
 // The next two are for printing
 #include <QPrinter>
 #include <QPainter>
@@ -90,7 +90,7 @@
 #include "award.h"
 #include "reference.h"
 #include "cabrillomanagement.h"
-
+#include "klognetwork.h"
 // To use the dxmap just uncomment out the define tag below. It will activate all relevant code. Still broken though.
 //#define DXMAP 1
 #ifdef DXMAP
@@ -133,7 +133,7 @@ class Klog : public QMainWindow, private Ui::klog
     LogBook templogbook; //The "not yet saved" logbook.
 
     //public:
-    bool haveWorld();
+    void haveWorld();
 
 //	virtual void run();
 
@@ -162,6 +162,8 @@ class Klog : public QMainWindow, private Ui::klog
     void filePrint();
     //void printLabels(); // Generate the file for GLabels or KBarcode
     void slothamlibUpdateFrequency();
+    void slotUpdateCTYDATFile();
+    void slotUpdateCTYDATFileManually();
 
 //	void adifFileSave();
     void adifTempFileSave(const QString& fn, LogBook lb, bool manualSave);  // To save the templog automatically after each QSO is added
@@ -239,7 +241,7 @@ class Klog : public QMainWindow, private Ui::klog
     Qso qso, qsoSelected, qsoSearchSelected;
 //	CabrilloManagement cabrilloLog;
 //	Qso previousQso;       // This and workedCall is to check if a call has been previously
-
+    bool requestDownloadctydat;
     bool completeWithPrevious;	// Configuration parameter
     bool completedWithPrevious;
     bool qsoSelectedBool, qsoSearchSelectedBool; 	//To know if a QSO has been selected at least once
@@ -308,6 +310,7 @@ class Klog : public QMainWindow, private Ui::klog
     void showTip();
     QString returnLines(const QString& tword); //Puts \n where \\n
    void showMenuRightButtoncreateActions();
+   bool checkCTYDATFile(); // Checks if the cty.dat file is in the ~/.klog directory
 //    void showMenuRightButtoncreateMenus();
 //    void showMenuRightButtoncontextMenuEvent(QContextMenuEvent *event);
 //    int band2Num(const QString &tband);
@@ -343,6 +346,7 @@ class Klog : public QMainWindow, private Ui::klog
 
     QPalette palette; // For cluster
     QPainter clusterPainter; // For cluster
+    QPalette qrzDefaultPalette, qrzWorkedB4Palette; // palette for the QRZLineEdit to now if a QRZ has been previously worked.
     QColor confirmedColor;
     QColor workedColor;
     QColor neededColor;
@@ -459,12 +463,16 @@ class Klog : public QMainWindow, private Ui::klog
     QString serialPort;
     QTimer *hamlibtimer;
     QMenu *qsoMenu;
-//    QMenu *searchRightButtonMenu;
+
+    
     QAction *delQSOAct;
     QAction *recSenQSOAct;
     QAction *recQSOAct;
     QAction *senQSOAct;
+   // QAction *actionUpdateCtyDat;
+    //QAction *actionUpdateCtyDatManually;
     QActionGroup *qsoActionsGroup;
+    
 };
 
 class dxClusterSpotItem : public QListWidgetItem {
