@@ -490,24 +490,24 @@ QChar Qso::isQslRec(){
 }
 
 bool Qso::gotTheQSL(){  // Ask if i have his QSL
-//qDebug() << "Qso::gotTheQSL" ;
+//qDebug() << "Qso::gotTheQSL"  << endl;
 //cout << "QSO::gotTheQSL: " << getQrz() << endl;
         if (qslRecc == 'Y'){
-//	   qDebug() << "Qso::gotTheQSL - Y (" << getQrz() << ")" << endl ;
+	   //qDebug() << "Qso::gotTheQSL - Y (" << getQrz() << ")" << endl ;
            return true;
         }else{
-//	  qDebug() << "Qso::gotTheQSL - N (" << getQrz() << ")" << endl ;
+	  //qDebug() << "Qso::gotTheQSL - N (" << getQrz() << ")" << endl ;
 	  return false;
         }
 }
 
 bool Qso::sentTheQSL(){ // Did i sent my QSL?
-//qDebug() << "Qso::sentTheQSL" ;
+//qDebug() << "Qso::sentTheQSL"  << endl;
   if (qslSenc == 'Y'){
 //    qDebug() << "Qso::sentTheQSL: YES" ;
     return true;
   }else{
-//    qDebug() << "Qso::sentTheQSL: NO" ;
+    //qDebug() << "Qso::sentTheQSL: NO" << endl;
     return false;
   }
 }
@@ -875,8 +875,8 @@ QString Qso::getCheck() const{return check;};                // Contest check
 void Qso::setClass(const QString &tcclass){cclass = checkisNotAdif(tcclass);}; // Contest class
 QString Qso::getClass() const{return cclass;};                // Contest class
 
-void Qso::clearQso(){
-        //cout << "Qso::clearQso" << endl;
+void Qso::clear(){
+        //cout << "Qso::clear" << endl;
 //qrz = "";        // CALL
 //numb = 0;           // STX
 //  QDateTime dateTime; // QSO_DATE/TIME_ON YYYYMMDD - Time HHMM (0000-2359)
